HoprState

Enum HoprState 

pub enum HoprState {
    Uninitialized = 0,
    WaitingForFunds = 1,
    CheckingBalance = 2,
    ValidatingNetworkConfig = 3,
    CheckingOnchainAddress = 4,
    RegisteringSafe = 5,
    AnnouncingNode = 6,
    AwaitingKeyBinding = 7,
    InitializingServices = 8,
    Running = 9,
    Terminated = 10,
}
An enum representing the current state of the HOPR node.

The states represent granular steps in the node initialization and lifecycle, providing detailed progress information suitable for UI applications.

Variants



Uninitialized = 0

Node instance created but not yet started



WaitingForFunds = 1

Waiting for the node wallet to receive initial funding



CheckingBalance = 2

Verifying the wallet has sufficient balance to operate



ValidatingNetworkConfig = 3

Validating network parameters like ticket price and winning probability



CheckingOnchainAddress = 4

Subscribing to on-chain account announcements



RegisteringSafe = 5

Registering the Safe contract with this node



AnnouncingNode = 6

Announcing node multiaddresses on the blockchain



AwaitingKeyBinding = 7

Waiting for the node’s key binding to appear on-chain



InitializingServices = 8

Initializing internal services (sessions, tickets, transport, channels)



Running = 9

Node is fully operational and ready for use



Terminated = 10

Node has been shut down