Struct ChannelBuilder
pub struct ChannelBuilder {
source: Option<Address>,
destination: Option<Address>,
balance: Option<Balance<WxHOPR>>,
ticket_index: u64,
status: ChannelStatus,
channel_epoch: u32,
}Expand description
Builder for ChannelEntry.
Fields
source: Option<Address>destination: Option<Address>balance: Option<Balance<WxHOPR>>ticket_index: u64status: ChannelStatuschannel_epoch: u32Implementations
impl ChannelBuilder
impl ChannelBuilder
pub const MAX_FUNDING_AMOUNT: u128
pub const MAX_FUNDING_AMOUNT: u128
Maximum possible funding amount channel: 10^25 wxHOPR
pub const MAX_CHANNEL_STAKE: u128
pub const MAX_CHANNEL_STAKE: u128
Maximum possible stake on the channel: 2^96 wxHOPR
pub fn source<A>(self, source: A) -> ChannelBuilder
pub fn source<A>(self, source: A) -> ChannelBuilder
Source of the channel.
Must be set along with ChannelBuilder::destination, or ChannelBuilder::between may be used
to set both.
pub fn destination<A>(self, destination: A) -> ChannelBuilder
pub fn destination<A>(self, destination: A) -> ChannelBuilder
Destination of the channel.
Must be set along with ChannelBuilder::source, or ChannelBuilder::between may be used
to set both.
pub fn between<A, B>(self, source: A, destination: B) -> ChannelBuilder
pub fn between<A, B>(self, source: A, destination: B) -> ChannelBuilder
Sets both source and destination of the channel.
This function or ChannelBuilder::source and ChannelBuilder::destination must be called.
pub fn amount<A>(self, amount: A) -> ChannelBuilderwhere
A: Into<U256>,
pub fn amount<A>(self, amount: A) -> ChannelBuilderwhere
A: Into<U256>,
Sets the stake amount on the channel in wei wxHOPR tokens.
This function or ChannelBuilder::balance must be called.
pub fn balance(self, balance: Balance<WxHOPR>) -> ChannelBuilder
pub fn balance(self, balance: Balance<WxHOPR>) -> ChannelBuilder
Sets specific HoprBalance as the stake on the channel.
This function or ChannelBuilder::amount must be called.
pub fn ticket_index(self, ticket_index: u64) -> ChannelBuilder
pub fn ticket_index(self, ticket_index: u64) -> ChannelBuilder
Ticket index of the channel.
Default is 0, maximum is 2^48 - 1.
pub fn status(self, status: ChannelStatus) -> ChannelBuilder
pub fn status(self, status: ChannelStatus) -> ChannelBuilder
Status of the channel.
The default is ChannelStatus::Open.
pub fn epoch(self, channel_epoch: u32) -> ChannelBuilder
pub fn epoch(self, channel_epoch: u32) -> ChannelBuilder
Epoch of the channel.
Default is 1, maximum is 2^24 - 1.
pub fn build(self) -> Result<ChannelEntry, CoreTypesError>
pub fn build(self) -> Result<ChannelEntry, CoreTypesError>
Tries to build the ChannelEntry.
Returns an error if values are out of range.