Struct ChannelEntry
pub struct ChannelEntry {
pub source: Address,
pub destination: Address,
pub balance: Balance<WxHOPR>,
pub ticket_index: u64,
pub status: ChannelStatus,
pub channel_epoch: u32,
id: HashBase<CoreWrapper<Keccak256Core>>,
}Expand description
Overall description of a channel
Fields
source: AddressSource address of the channel.
destination: AddressDestination address of the channel.
balance: Balance<WxHOPR>Stake amount on the channel in wxHOPR tokens.
ticket_index: u64Next ticket index of the channel.
status: ChannelStatusCurrent status of the channel.
channel_epoch: u32Epoch of the channel.
id: HashBase<CoreWrapper<Keccak256Core>>Implementations
impl ChannelEntry
impl ChannelEntry
pub fn builder() -> ChannelBuilder
pub fn builder() -> ChannelBuilder
Creates a new ChannelBuilder.
pub fn new(
source: Address,
destination: Address,
balance: Balance<WxHOPR>,
ticket_index: u64,
status: ChannelStatus,
channel_epoch: u32,
) -> ChannelEntry
👎Deprecated since 1.3.0: use ChannelBuilder instead
pub fn new( source: Address, destination: Address, balance: Balance<WxHOPR>, ticket_index: u64, status: ChannelStatus, channel_epoch: u32, ) -> ChannelEntry
DEPRECATED Construct a new channel entry.
pub fn get_id(&self) -> &HashBase<CoreWrapper<Keccak256Core>>
pub fn get_id(&self) -> &HashBase<CoreWrapper<Keccak256Core>>
Generates the channel ID using the source and destination address
pub fn closure_time_passed(&self, current_time: SystemTime) -> bool
pub fn closure_time_passed(&self, current_time: SystemTime) -> bool
Checks if the closure time of this channel has passed.
Also returns false if the channel closure has not been initiated (it is in Open state).
Returns also true if the channel is in Closed state.
pub fn remaining_closure_time(
&self,
current_time: SystemTime,
) -> Option<Duration>
pub fn remaining_closure_time( &self, current_time: SystemTime, ) -> Option<Duration>
Calculates the remaining channel closure grace period.
Returns None if the channel closure has not been initiated yet (channel is in Open state).
pub fn closure_time_at(&self) -> Option<SystemTime>
pub fn closure_time_at(&self) -> Option<SystemTime>
Returns the earliest time the channel can transition from PendingToClose into Closed.
If the channel is not in the PendingToClose state, it returns None.
pub fn direction(&self, me: &Address) -> Option<ChannelDirection>
pub fn direction(&self, me: &Address) -> Option<ChannelDirection>
Determines the channel direction given the self-address.
Returns None if neither source nor destination are equal to me.
pub fn orientation(&self, me: &Address) -> Option<(ChannelDirection, Address)>
pub fn orientation(&self, me: &Address) -> Option<(ChannelDirection, Address)>
Determines the channel’s direction and counterparty relative to me.
Returns None if neither source nor destination are equal to me.
pub fn diff(&self, other: &ChannelEntry) -> Vec<ChannelChange>
pub fn diff(&self, other: &ChannelEntry) -> Vec<ChannelChange>
Makes a diff of this channel (left) and the other channel (right).
The channels must have the same ID.
See ChannelChange