Struct HoprSenderId
pub struct HoprSenderId(/* private fields */);Expand description
Identifier of a single packet sender.
This consists of two parts:
HoprSenderId::pseudonymof the senderHoprSenderId::surb_idis an identifier a single SURB that routes the packet back to the sender.
The surb_id always identifies a single SURB. The instance can be turned into a pseudorandom
sequence using HoprSenderId::into_sequence to create identifiers for more SURBs
with the same pseudonym.
Implementations
impl HoprSenderId
impl HoprSenderId
pub fn new(pseudonym: &SimplePseudonym) -> HoprSenderId
pub fn from_pseudonym_and_id( pseudonym: &SimplePseudonym, id: [u8; 8], ) -> HoprSenderId
pub fn pseudonym(&self) -> SimplePseudonym
pub fn surb_id(&self) -> [u8; 8]
pub fn into_sequence(self) -> impl Iterator<Item = HoprSenderId>
pub fn into_sequence(self) -> impl Iterator<Item = HoprSenderId>
Creates a pseudorandom sequence of IDs.
Each item has the same pseudonym
but different surb_id.
The surb_id of the n-th item (n > 1) is computed as Blake3(n-1 || I_prev)
where I_prev is the whole n-1-th ID, the n is represented as big-endian and
|| denotes byte-array concatenation.
The first item (n = 1) is always self.
The entropy of the whole pseudorandom sequence is completely given by self (the first
item in the sequence). It follows that the next element of the sequence can be computed
by just knowing any preceding element; therefore, the sequence is fully predictable
once an element is known.