pub struct Hopr<Chain, Graph, Net, TMgr> {
pub(crate) transport_id: OffchainKeypair,
pub(crate) chain_id: NodeOnchainIdentity,
pub(crate) cfg: HoprLibConfig,
pub(crate) state: Arc<AtomicHoprState>,
pub(crate) transport_api: HoprTransport<Chain, Graph, Net>,
pub(crate) chain_api: Chain,
pub(crate) ticket_event_subscribers: (Sender<TicketEvent>, InactiveReceiver<TicketEvent>),
pub(crate) ticket_manager: TMgr,
pub(crate) processes: AbortableList<HoprLibProcess>,
}Expand description
HOPR main object providing the entire HOPR node functionality
Instantiating this object creates all processes and objects necessary for
running the HOPR node. Once created, the node can be started using the
run() method.
Externally offered API should be enough to perform all necessary tasks with the HOPR node manually, but it is advised to create such a configuration that manual interaction is unnecessary.
As such, the hopr_lib serves mainly as an integration point into Rust programs.
Fields
transport_id: OffchainKeypairchain_id: NodeOnchainIdentitycfg: HoprLibConfigstate: Arc<AtomicHoprState>transport_api: HoprTransport<Chain, Graph, Net>chain_api: Chainticket_event_subscribers: (Sender<TicketEvent>, InactiveReceiver<TicketEvent>)ticket_manager: TMgrprocesses: AbortableList<HoprLibProcess>Implementations
Sourceimpl<Chain, Graph, Net, TMgr> Hopr<Chain, Graph, Net, TMgr>where
Chain: HoprChainApi + Clone + Send + Sync + 'static,
Graph: HoprGraphApi<HoprNodeId = OffchainPublicKey> + Clone + Send + Sync + 'static,
<Graph as NetworkGraphTraverse>::Observed: EdgeObservableRead + Send + 'static,
<Graph as NetworkGraphWrite>::Observed: EdgeObservableWrite + Send,
Net: NetworkView + NetworkStreamControl + Send + Sync + Clone + 'static,
impl<Chain, Graph, Net, TMgr> Hopr<Chain, Graph, Net, TMgr>where
Chain: HoprChainApi + Clone + Send + Sync + 'static,
Graph: HoprGraphApi<HoprNodeId = OffchainPublicKey> + Clone + Send + Sync + 'static,
<Graph as NetworkGraphTraverse>::Observed: EdgeObservableRead + Send + 'static,
<Graph as NetworkGraphWrite>::Observed: EdgeObservableWrite + Send,
Net: NetworkView + NetworkStreamControl + Send + Sync + Clone + 'static,
pub fn config(&self) -> &HoprLibConfig
pub(crate) fn error_if_not_in_state( &self, state: HoprState, error: String, ) -> Result<()>
pub(crate) async fn connect_to_with_transport_config( &self, destination: Address, target: SessionTarget, cfg: SessionClientConfig, ) -> Result<(HoprSession, HoprSessionConfigurator), HoprLibError>
Sourceimpl<Chain, Graph, Net, TMgr> Hopr<Chain, Graph, Net, TMgr>where
Chain: HoprChainApi + ComponentStatusReporter + Clone + Send + Sync + 'static,
Net: NetworkView + NetworkStreamControl + Send + Sync + Clone + 'static,
Graph: HoprGraphApi<HoprNodeId = OffchainPublicKey> + NetworkGraphConnectivity<NodeId = OffchainPublicKey> + Clone + Send + Sync + 'static,
<Graph as NetworkGraphTraverse>::Observed: EdgeObservableRead + Send + 'static,
<Graph as NetworkGraphWrite>::Observed: EdgeObservableWrite + Send,
TMgr: Send + Sync + 'static,
impl<Chain, Graph, Net, TMgr> Hopr<Chain, Graph, Net, TMgr>where
Chain: HoprChainApi + ComponentStatusReporter + Clone + Send + Sync + 'static,
Net: NetworkView + NetworkStreamControl + Send + Sync + Clone + 'static,
Graph: HoprGraphApi<HoprNodeId = OffchainPublicKey> + NetworkGraphConnectivity<NodeId = OffchainPublicKey> + Clone + Send + Sync + 'static,
<Graph as NetworkGraphTraverse>::Observed: EdgeObservableRead + Send + 'static,
<Graph as NetworkGraphWrite>::Observed: EdgeObservableWrite + Send,
TMgr: Send + Sync + 'static,
Sourcepub fn component_statuses(&self) -> NodeComponentStatuses
pub fn component_statuses(&self) -> NodeComponentStatuses
Returns per-component health statuses for the node.
When the node has reached Running, the aggregate node_state is
derived from component statuses (Running → Degraded → Failed).